@@ -37,3 +37,6 @@ class BpmnNode(ABC):
 
     def _get_property(self, key: str) -> Optional[str]:
         return self.__dict__[key] if key in self.__dict__ else None
+
+    def __getitem__(self, item):
+        return self.__dict__[item] if item in self.__dict__ else None
