@@ -1,7 +1,9 @@
-from typing import List, Dict, Optional
+from time import time
+from typing import List, Dict, Optional, Union
 
 from arrow_bpmn.__spi__.registry.event import Event
-from arrow_bpmn.engine.registry.abstract_event_registry import EventRegistry, NodeRef
+from arrow_bpmn.__spi__.registry.process_ref import ProcessRef
+from arrow_bpmn.engine.registry.abstract_event_registry import EventRegistry, NodeRef, EventStr
 
 
 class InMemoryEventRegistry(EventRegistry):
@@ -14,28 +16,35 @@ class InMemoryEventRegistry(EventRegistry):
     """
 
     def __init__(self):
-        self.event_sources: Dict[str, Dict[str, int]] = {}
-        self.event_targets: Dict[str, Dict[str, int]] = {}
+        self.event_sources: Dict[str, Dict[str, float]] = {}
+        self.event_targets: Dict[str, Dict[str, float]] = {}
+        self.process_events: Dict[str, Dict[str, float]] = {}
         self.consumables: List[str] = []
 
     def create_subscription(self, event: Event, node_ref: NodeRef, consumable: bool):
+        timestamp = time()
         event_key = str(event)
         node_key = str(node_ref)
 
         if event_key not in self.event_sources:
-            self.event_sources[event_key] = {node_key: 0}
+            self.event_sources[event_key] = {node_key: timestamp}
         else:
-            self.event_sources[event_key][node_key] = 0
+            self.event_sources[event_key][node_key] = timestamp
 
         if node_key not in self.event_targets:
-            self.event_targets[node_key] = {event_key: 0}
+            self.event_targets[node_key] = {event_key: timestamp}
         else:
-            self.event_targets[node_key][event_key] = 0
+            self.event_targets[node_key][event_key] = timestamp
 
         if consumable:
             self.consumables.append(str(node_ref))
 
-    def delete_subscription(self, event: Optional[Event], node_ref: NodeRef):
+        process_key = str(ProcessRef(node_ref.group, node_ref.process_id))
+        if process_key not in self.process_events:
+            self.process_events[process_key] = {}
+        self.process_events[process_key][event_key] = timestamp
+
+    def delete_subscription(self, event: Optional[Union[Event, EventStr]], node_ref: NodeRef):
         event_refs = []
 
         if event is None:
@@ -48,7 +57,15 @@ class InMemoryEventRegistry(EventRegistry):
             del self.event_targets[str(node_ref)][event_ref]
             del self.event_sources[event_ref][str(node_ref)]
 
-    def get_subscriptions(self, event: Event) -> List[NodeRef]:
+    def delete_subscriptions(self, process_ref: ProcessRef):
+        event_refs = self.process_events[str(process_ref)].keys()
+
+        for event_ref in event_refs:
+            for node_ref in self.get_subscriptions(event_ref):
+                self.delete_subscription(event_ref, node_ref)
+
+    # TODO: sort by timestamps
+    def get_subscriptions(self, event: Union[Event, EventStr]) -> List[NodeRef]:
         node_refs = []
 
         if str(event) in self.event_sources:
