@@ -36,7 +36,7 @@ class MessageStartEvent(NoneStartEvent, EventRegistryAware):
 
     def with_event_registry(self, process_ref: ProcessRef, event_registry: EventRegistry):
         event = MessageEvent(process_ref.group, self.message)
-        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id))
+        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id), False)
 
     def __repr__(self):
         return f"MessageStartEvent({self.id})"
