@@ -29,7 +29,7 @@ class ReceiveTask(BpmnNode):
             return state, [CompleteAction(self.id)] + actions
 
         event = MessageEvent(environment.group, environment.get_message(self.message_ref))
-        return state, [QueueAction(self.id, event=event)]
+        return state, [QueueAction(self.id, event=event, save_state=True)]
 
     def __repr__(self):
         return f"ReceiveTask({self.id})"
